from colorama import init, Fore
from pytube import YouTube

import os, time, platform
from path_resources import get_path, get_command
from menu import print_menu, video_menu, audio_menu
from youtube import get_url, download_video, download_audio_win, download_audio

init()

path = get_path()
clear = get_command()

# Funcion main
def main():
    opc = print_menu()
    modes(opc)


# Funcion de los modos u opciones
def modes(opc):
    if opc == 1:
        vid_opc = video_menu()
        if vid_opc == 1:
            url = get_url()
            download_video(url, path)
        elif vid_opc == 2:
            num_vid = int(
                input(Fore.LIGHTYELLOW_EX + "Number of videos: " + Fore.LIGHTGREEN_EX)
            )
			# Por cada video se descarga 
            for k in range(num_vid):
                video = input(
                    Fore.LIGHTGREEN_EX + f"{k + 1}. Url: " + Fore.LIGHTYELLOW_EX + ""
                )
                download_video(video, path)

        else:
            print(Fore.RED + "Error option is not recognized")
            print(Fore.LIGHTGREEN_EX + "Moving to main menu")
            time.sleep(2.0)
            os.system(clear)
            main()

    elif opc == 2:
        vid_opc = audio_menu()
        if vid_opc == 1:
            url = get_url()
            yt = YouTube(url)
            if platform.system() == "Windows":
                download_audio_win(yt, path)
            else:
                download_audio(yt, path)

            print(Fore.GREEN + "Download Finish :D")
        elif vid_opc == 2:
            num_mp3 = int(
                input(Fore.LIGHTBLUE_EX + "Number of audios or mp3: " + Fore.YELLOW)
            )
            for i in range(num_mp3):
                url = get_url()
                yt = YouTube(url)
                if platform.system() == "Windows":
                    download_audio_win(yt, path)
                else:
                    download_audio(yt, path)
                print(Fore.GREEN + f"Audio {i + 1} downloaded sucessfully")
        else:
            print(Fore.RED + "Error option is not recognized")
            print(Fore.LIGHTGREEN_EX + "Moving to main menu")
            time.sleep(2.0)
            os.system(clear)
            main()

    elif opc == 3:
        os.system(clear)
        time.sleep(0.5)
        print(Fore.LIGHTBLUE_EX + "End of the program :D")

    else:
        print(Fore.LIGHTBLUE_EX + "End of the program :D")


if __name__ == '__main__':
    main()




import platform
from pathlib import Path
from getpass import getuser


def get_path():
    if platform.system() == "Windows":
        home = Path.home()
        path = f"{home}/Downloads/"

    else:
        usuario = getuser()
        path = f"/home/{usuario}/Downloads"

    return path


def get_command():
    if platform.system() == "Windows":
        command = "cls"

    else:
        command = "clear"

    return command



from tqdm import tqdm
from time import sleep
from colorama import Style, Fore

def loading_bar(message):
    Style.RESET_ALL
    if message == None:
      for i in tqdm(range(1000), Fore.WHITE + "Finalizando descarga"):
          sleep(0.001)

    else:
      for i in tqdm(range(1000), Fore.WHITE + message):
          sleep(0.001)


import os, shutil, subprocess
from uuid import uuid4
from pytube import YouTube
from colorama import Fore

from loading import loading_bar

def get_url():
    url = input(Fore.LIGHTWHITE_EX + "Url: " + Fore.LIGHTYELLOW_EX + "")
    return url

def download_video(url, path):
    yt = YouTube(url)
    print(Fore.BLUE + "Downloading Video")
    yt.streams.filter(progressive=True, file_extension="mp4").first().download(
        path
    )
    loading_bar()
    print(Fore.LIGHTBLUE_EX + "Download Finish :D")

def download_audio_win(yt, path):
    print(Fore.BLUE + "Downloading Audio")
    video = yt.streams.filter(only_audio=True).first()
    fileDownloaded = video.download(path)
    base, ext = os.path.splitext(fileDownloaded)
    newFile = base + ".mp3"
    shutil.copy(fileDownloaded, newFile)
    vPath = os.path.join(path, fileDownloaded)
    os.remove(vPath)
    loading_bar()

def download_audio(yt, path):
    id = uuid4() 
    print(Fore.BLUE + "Downloading...")
    yt.streams.filter(
        progressive=True, file_extension="mp4"
    ).first().download(path, filename=f"{id}.mp4")
    parent_dir = path
    default_filename = f"{id}.mp4"
    new_filename = input("Ingresa el nuevo nombre (con extension .mp3): ")
    print(Fore.BLUE + "Converting to audio")
    subprocess.run(
        [
            "ffmpeg",
            "-i",
            os.path.join(parent_dir, default_filename),
            os.path.join(parent_dir, new_filename),
        ],
        stdout=subprocess.DEVNULL,
        stderr=subprocess.STDOUT,
    )
    vid_path = os.path.join(parent_dir, default_filename)
    os.remove(vid_path)
    loading_bar('Finalizando conversion')


import setuptools

with open("README.md", "r", encoding="utf-8") as f:
    README = f.read()

setuptools.setup(
    name="yt_ripper",
    version="0.0.1",
    author="Jonathani Atticus64",
    author_email="jonaenglish64@gmail.com",
    description="Project with Python to download videos and mp3 files of youtube in the terminal", 
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/atticus64/pycritty",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX :: Linux",
        "Topic :: Terminals :: Terminal Emulators/X Terminals"
    ],
    keywords="youtube",
    python_requires='>=3.6',
    install_requires=["colorama", "pytube", "tqdm"],
    include_package_data=True,
    entry_points={
        "console_scripts": ["ytripper = yt_ripper.main:main"]
    },
)



import os
from colorama import Fore, Style

from path_resources import get_command

clear = get_command()


def print_menu():
    os.system(clear)
    print(Fore.BLUE + "Terminal Application to dowload videos and mp3")
    print(Fore.CYAN + "1. Download a Video")
    print(Fore.GREEN + "2. Download a Video to Mp3")
    print(Fore.RED + "3. Exit")
    print(Fore.WHITE + "")
    opc = int(input(Fore.YELLOW + "What you want to do? " + Fore.WHITE))
    return opc


def video_menu():
    os.system(clear)
    print(Fore.CYAN + "Download Video Section")
    print(Fore.LIGHTBLUE_EX + "1. Download 1 video")
    print(Fore.BLUE + "2. Download a group of videos")
    print(Style.RESET_ALL + "")
    vid_opc = int(input(Fore.YELLOW + "Option: " + Fore.LIGHTMAGENTA_EX))
    return vid_opc


def audio_menu():
    os.system(clear)
    print(Fore.LIGHTCYAN_EX + "Download Video to Mp3 Section")
    print(Fore.MAGENTA + "1. Download 1 mp3 audio")
    print(Fore.BLUE + "2. Download a group of mp3 audios")
    print("")
    aud_opc = int(input(Fore.YELLOW + "Option: " + Fore.LIGHTCYAN_EX))
    return aud_opc
